@@ -23,18 +23,21 @@ class RTSS_Writer:
 
         #data spécifique à la série ou on dessine les contours 
         serie = Series(serie_path)
-        self.first_metadata = serie.get_first_instance_metadata()
-        self.image_position = self.first_metadata.get_image_position()
-        self.pixel_spacing = self.first_metadata.get_pixel_spacing()
-        print('Origin :', self.image_position)
-
-        serie.get_instances_ordered()
+        self.instances = serie.get_instances_ordered()
+        self.image_position = self.instances[0].get_image_position()
+        self.pixel_spacing = self.instances[0].get_pixel_spacing()
         self.pixel_spacing.append(serie.get_z_spacing())
-        print('Spacing :', self.pixel_spacing)
         
         #Get list of every sop instance uid 
         self.list_all_SOPInstanceUID = serie.get_all_SOPInstanceIUD()
     
+        #self.first_metadata = serie.get_first_instance_metadata()
+
+        #str to float 
+        for i in range(len(self.image_position)):
+            self.image_position[i] = float(self.image_position[i])
+            self.pixel_spacing[i] = float(self.pixel_spacing[i])
+
 
         #dictionnaire entrée par l'utilisateur 
         self.dict_roi_data = dict_roi_data
@@ -95,19 +98,19 @@ class RTSS_Writer:
                   - StudyTime'             : 
         """     
         #from the serie 
-        self.dataset.AccessionNumber = self.first_metadata.get_accession_number()
-        self.dataset.PatientBirthData = self.first_metadata.get_patient_birth_date()
-        self.dataset.PatientID = self.first_metadata.get_patient_id()
-        self.dataset.PatientName = self.first_metadata.get_patient_name()
-        self.dataset.PatientSex = self.first_metadata.get_patient_sex()
-        #self.dataset.PysiciansOfRecord = self.first_metadata.get_physicians_of_record()
-        #self.dataset.ReferringPhysicianName = self.first_metadata.get_referring_physician_name()
-        #self.dataset.SpecificCharacterSet = self.first_metadata.get_specific_character_set()
-        self.dataset.StudyData = self.first_metadata.get_study_date()
-        self.dataset.StudyDescription = self.first_metadata.get_study_description()
-        self.dataset.StudyID = self.first_metadata.get_study_id()
-        self.dataset.StudyInstanceUID = self.first_metadata.get_study_instance_uid()
-        self.dataset.StudyTime = self.first_metadata.get_study_time()
+        self.dataset.AccessionNumber = self.instances[0].get_accession_number()
+        self.dataset.PatientBirthData = self.instances[0].get_patient_birth_date()
+        self.dataset.PatientID = self.instances[0].get_patient_id()
+        self.dataset.PatientName = self.instances[0].get_patient_name()
+        self.dataset.PatientSex = self.instances[0].get_patient_sex()
+        self.dataset.PysiciansOfRecord = self.instances[0].get_physicians_of_record()
+        self.dataset.ReferringPhysicianName = self.instances[0].get_referring_physician_name()
+        self.dataset.SpecificCharacterSet = self.instances[0].get_specific_character_set()
+        self.dataset.StudyData = self.instances[0].get_study_date()
+        self.dataset.StudyDescription = self.instances[0].get_study_description()
+        self.dataset.StudyID = self.instances[0].get_study_id()
+        self.dataset.StudyInstanceUID = pydicom.uid.generate_uid() #self.instances[0].get_study_instance_uid()
+        self.dataset.StudyTime = self.instances[0].get_study_time()
 
         #specific new tags for the serie 
 
@@ -121,14 +124,14 @@ class RTSS_Writer:
         self.dataset.ReviewDate = '' #because UNAPPROVED
         self.dataset.ReviewTime = '' #because UNAPPROVED
         self.dataset.ReviewerName = '' #because UNAPPROVED
-        self.dataset.SeriesDescription = 'RTSTRUCT generated by dicom_to_cnn'
+        self.dataset.SeriesDescription = self.dict_roi_data['Description']
         self.dataset.SeriesInstanceUID = pydicom.uid.generate_uid()
         self.dataset.SeriesNumber = random.randint(0,1e3)
         self.dataset.SOPClassUID = '1.2.840.10008.5.1.4.1.1.481.3' 
         #self.dataset.SOPInstanceUID = file_meta.MediaStorageSOPInstanceUID 
         self.dataset.StructureSetDate = dt.strftime('%Y%m%d')
-        self.dataset.StructureSetDescription = 'RTSTRUCT generated by dicom_to_cnn'
-        self.dataset.StructureSetLabel = 'test'
+        self.dataset.StructureSetDescription = self.dict_roi_data['Description']
+        self.dataset.StructureSetLabel = self.dict_roi_data['Description']
         self.dataset.StructureSetTime = dt.strftime('%H%M%S.%f')
 
         return None 
@@ -137,7 +140,7 @@ class RTSS_Writer:
 
     #StructureSetROISequence
     def set_StructureSetROISequence(self):
-        referenced_frame_of_reference_uid = self.first_metadata.get_frame_of_reference_uid()
+        referenced_frame_of_reference_uid = self.instances[0].get_frame_of_reference_uid()
         self.dataset.StructureSetROISequence = StructureSetROISequence(self.mask, self.dict_roi_data).create_StructureSetROISequence(self.pixel_spacing, referenced_frame_of_reference_uid)
         
 
@@ -148,23 +151,21 @@ class RTSS_Writer:
 
     #ROIContourSequence 
     def set_ROIContourSequence(self):
-        referenced_sop_class_uid = self.first_metadata.get_sop_class_uid()
-        self.dataset.ROIContourSequence = ROIContourSequence(self.mask, self.dict_roi_data).create_ROIContourSequence(referenced_sop_class_uid, self.image_position, self.pixel_spacing, self.list_all_SOPInstanceUID)
+        referenced_sop_class_uid = self.instances[0].get_sop_class_uid()
+        self.dataset.ROIContourSequence = ROIContourSequence(self.mask, self.dict_roi_data).create_ROIContourSequence(referenced_sop_class_uid, self.image_position, self.pixel_spacing, self.list_all_SOPInstanceUID, self.instances)
 
     #ReferencedFrameOfReferenceSequence 
     def set_ReferencedFrameOfReferenceSequence(self):
-        frame_of_reference_uid = self.first_metadata.get_frame_of_reference_uid()
-        series_instance_uid = self.first_metadata.get_series_instance_uid()
-        study_instance_uid = self.first_metadata.get_study_instance_uid()
-        sop_class_uid = self.first_metadata.get_sop_class_uid()
+        frame_of_reference_uid = self.instances[0].get_frame_of_reference_uid()
+        series_instance_uid = self.instances[0].get_series_instance_uid()
+        study_instance_uid = self.instances[0].get_study_instance_uid()
+        sop_class_uid = self.instances[0].get_sop_class_uid()
         self.dataset.ReferencedFrameOfReferenceSequence = ReferencedFrameOfReferenceSequence().create_ReferencedFrameOfReferenceSequence(frame_of_reference_uid, sop_class_uid, self.list_all_SOPInstanceUID, series_instance_uid, study_instance_uid)
 
 
     def save_file(self, filename, directory_path):
         filemeta = self.generates_file_meta()
-
         filedataset = pydicom.dataset.FileDataset(filename, self.dataset, preamble=b"\0" * 128, file_meta=filemeta, is_implicit_VR = True, is_little_endian = True )
-
         filedataset.save_as(os.path.join(directory_path, filename))
 
         return None 
